@@ -34,8 +34,4 @@ def main():
     print("")
 
 
-if __name__ == "__main__":
-    main()
-else:
-    pass
-
+main()
